"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolvePath = exports.parsePath = exports.cssExportsToJs = exports.codeWithSourceMap = void 0;
const path_1 = __importDefault(require("path"));
const codeWithSourceMap = (code, map) => {
    return code + '/*# sourceMappingURL=data:application/json;base64,' + Buffer.from(map).toString('base64') + ' */';
};
exports.codeWithSourceMap = codeWithSourceMap;
const cssExportsToJs = (exports, entryFile) => {
    const keys = Object.keys(exports).sort();
    const values = keys.map((key) => exports[key]);
    const exportCode = `export default ${JSON.stringify(Object.fromEntries(keys.map((key, index) => [key, values[index].name])))};`;
    if (entryFile) {
        return `import '${entryFile}';\n${exportCode}`;
    }
    return exportCode;
};
exports.cssExportsToJs = cssExportsToJs;
/**
 * 从路径中解析文件路径和 query
 */
const parsePath = (path) => {
    const queryIndex = path.indexOf('?');
    if (queryIndex === -1) {
        return { path: path, query: '' };
    }
    else {
        return {
            path: path.slice(0, queryIndex),
            query: path.slice(queryIndex + 1),
        };
    }
};
exports.parsePath = parsePath;
function resolvePath(args) {
    const { path, query } = (0, exports.parsePath)(args.path);
    let absolutePath = path;
    if (path_1.default.isAbsolute(absolutePath)) {
        absolutePath = absolutePath;
    }
    else {
        absolutePath = path_1.default.join(args.resolveDir, absolutePath);
    }
    return { path: absolutePath, query };
}
exports.resolvePath = resolvePath;
